@@ -2,8 +2,7 @@
 Basic utilities for working with notes, base classes for objects etc.
 """
 import itertools
-from collections import namedtuple
-from typing import Hashable, List, Set
+from typing import Hashable, List
 
 from jchord.knowledge import MAJOR_SCALE_OFFSETS, CHROMATIC, ENHARMONIC
 
@@ -54,17 +53,33 @@ class CompositeObject(object):
             raise StopIteration
 
     def __repr__(self):
-        return "{}({})".format(
-            type(self).__name__, ", ".join(repr(key) for key in self._keys())
-        )
+        return f"{type(self).__name__}({', '.join(repr(key) for key in self._keys())})"
 
 
 class Note(CompositeObject):
-    """Represents an absolute note with a name and an octave.
+    """
+    Represents an absolute note with a name and an octave.
+    To create a Note, provide the name as a string and the octave as an integer:
 
-    Two `Note`s are equal if they have the same name and octave,
-    or if they have the same octave and their names are enharmonic
-    (so `Note('A#', 4) == Note('Gb', 4)`)
+    >>> Note(name="A", octave=3)
+    Note('A', 3)
+
+    Two instances of ``Note`` are equal if they have the same name and octave,
+    or if they have the same octave and their names are enharmonic:
+
+    >>> Note('G#', 4) == Note('Ab', 4)
+    True
+    >>> Note('G#', 4) == Note('Ab', 3)
+    False
+
+    You can subtract two ``Note`` instances to get the number of semitones between them:
+
+    >>> Note('G#', 4) - Note('Ab', 3)
+    12
+    >>> Note('Ab', 3) - Note('G#', 4)
+    -12
+
+    ``Note`` is hashable, so instances can be used as dictionary keys or members of sets.
     """
 
     def __init__(self, name: str, octave: int):
@@ -101,14 +116,21 @@ class Note(CompositeObject):
                 return other_name == sharp
         return False
 
+    def __sub__(self, other):
+        """Returns the number of semitones between the two notes"""
+        from jchord import midi
+
+        return midi.note_to_midi(self) - midi.note_to_midi(other)
+
     def pitch(self) -> float:
         """Returns the absolute pitch of the note in Hz.
 
-        Examples (equalities are approximate):
-
-        * `Note("A", 4).pitch() == 440.0`
-        * `Note("A", 0).pitch() == 27.5`
-        * `Note("C", 4).pitch() == 261.62556`
+        >>> Note("A", 4).pitch()
+        440.0
+        >>> Note("A", 0).pitch()
+        27.5
+        >>> Note("C", 4).pitch()
+        261.6255653005986
         """
         from jchord import midi
 
@@ -121,7 +143,7 @@ class Note(CompositeObject):
                     return Note(name=CHROMATIC[0], octave=self.octave + 1)
                 else:
                     return Note(name=CHROMATIC[i + 1], octave=self.octave)
-        raise RuntimeError("Can't shift up {}".format(self))
+        raise RuntimeError(f"Can't shift up {self}")
 
     def _shift_down(self: "Note") -> "Note":
         for i, other in enumerate(CHROMATIC):
@@ -130,15 +152,15 @@ class Note(CompositeObject):
                     return Note(name=CHROMATIC[-1], octave=self.octave - 1)
                 else:
                     return Note(name=CHROMATIC[i - 1], octave=self.octave)
-        raise RuntimeError("Can't shift down {}".format(self))
+        raise RuntimeError(f"Can't shift down {self}")
 
     def transpose(self: "Note", shift: int) -> "Note":
         """Transposes the note by the given number of semitones.
 
-        Examples:
-
-        * `Note("C", 0).transpose(1) == Note("C#", 0)`
-        * `Note("C", 4).transpose(19) == Note("G", 5)`
+        >>> Note("C", 0).transpose(1)
+        Note('C#', 0)
+        >>> Note("C", 4).transpose(19)
+        Note('G', 5)
         """
         note = self
         if shift > 0:
@@ -149,15 +171,19 @@ class Note(CompositeObject):
                 note = note._shift_down()
         return note
 
-    def transpose_degree(self: "Note", shift: str) -> "Note":
-        """Transposes the given note by the given scale degree
-
-        Examples:
-
-        * `Note("C", 0).transpose_degree("b2") == Note("C#", 0)`
-        * `Note("C", 4).transpose_degree("12") == Note("G", 5)`
+    def transpose_degree(self: "Note", shift: str, down: bool = False) -> "Note":
         """
-        return self.transpose(degree_to_semitone(shift))
+        Transposes the given note by the given scale degree.
+
+        >>> Note("C", 0).transpose_degree("b2")
+        Note('C#', 0)
+        >>> Note("C", 4).transpose_degree("5")
+        Note('G', 4)
+        >>> Note("C", 4).transpose_degree("5", down=True)
+        Note('F', 3)
+        """
+        factor = -1 if down else 1
+        return self.transpose(factor * degree_to_semitone(shift))
 
 
 def split_to_base_and_shift(
@@ -255,12 +281,12 @@ def semitone_to_degree_options(semitone: int, max_accidentals: int = 1) -> List[
         for n_accidentals in range(max_accidentals + 1):
             if semitone == cand_semitone - n_accidentals:
                 options_with_priority.append(
-                    ("{}{}".format("b" * n_accidentals, cand_degree), n_accidentals)
+                    (f"{'b' * n_accidentals}{cand_degree}", n_accidentals)
                 )
             if semitone == cand_semitone + n_accidentals:
                 options_with_priority.append(
                     (
-                        "{}{}".format("#" * n_accidentals, cand_degree),
+                        f"{'#' * n_accidentals}{cand_degree}",
                         n_accidentals + 0.5,
                     )
                 )
