@@ -191,21 +191,26 @@ def test_transpose(note_in, octave_in, shift, note_out, octave_out):
 
 
 @pytest.mark.parametrize(
-    "note_in, octave_in, shift, note_out, octave_out",
+    "note_in, octave_in, shift, down, note_out, octave_out",
     [
-        ("C", 0, "b2", "C#", 0),
-        ("C#", 0, "#1", "D", 0),
-        ("D", 0, "b2", "D#", 0),
-        ("B", 0, "b2", "C", 1),
-        ("B", 1, "#1", "C", 2),
-        ("B", 110, "#1", "C", 111),
-        ("C", 4, "5", "G", 4),
-        ("C", 4, "12", "G", 5),
-        ("A", 3, "b3", "C", 4),
+        ("C", 0, "b2", False, "C#", 0),
+        ("C", 0, "b2", True, "B", -1),
+        ("C#", 0, "#1", False, "D", 0),
+        ("D", 0, "b2", False, "D#", 0),
+        ("B", 0, "b2", False, "C", 1),
+        ("B", 1, "#1", False, "C", 2),
+        ("B", 110, "#1", False, "C", 111),
+        ("C", 4, "5", False, "G", 4),
+        ("C", 4, "5", True, "F", 3),
+        ("C", 4, "12", False, "G", 5),
+        ("A", 3, "b3", False, "C", 4),
     ],
 )
-def test_transpose_degree(note_in, octave_in, shift, note_out, octave_out):
-    assert Note(note_in, octave_in).transpose_degree(shift) == (note_out, octave_out)
+def test_transpose_degree(note_in, octave_in, shift, down, note_out, octave_out):
+    assert Note(note_in, octave_in).transpose_degree(shift, down) == (
+        note_out,
+        octave_out,
+    )
 
 
 @pytest.mark.parametrize(
